@@ -13,6 +13,7 @@
 
 
 #include "calculator.h"
+#include "sharedrabundfloatvectors.hpp"
 
 /***********************************************************************/
 
@@ -22,6 +23,7 @@ public:
 	StructEuclidean() :  Calculator("structeuclidean", 1, false) {};
 	EstOutput getValues(SAbundVector*) {return data;};
 	EstOutput getValues(vector<SharedRAbundVector*>);
+    EstOutput getValues(vector<SharedRAbundFloatVector*>);
 	string getCitation() { return "http://www.mothur.org/wiki/Structeuclidean"; }
 private:
 	
