@@ -80,12 +80,11 @@ public:
 	string getCitation() { return "http://www.mothur.org/wiki/Dist.shared"; }
 	string getDescription()		{ return "generate a distance matrix that describes the dissimilarity among multiple groups"; }
 
-	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
 	
 private:
-    string exportFileName, output, sharedfile;
+    string exportFileName, output, sharedfile, clrfile, inputfile, format;
 	int numGroups, processors, iters, subsampleSize;
 	ofstream out;
 
@@ -97,6 +96,7 @@ private:
     int createProcesses(SharedRAbundVectors*&);
 	int driver(vector<SharedRAbundVector*>&, vector< vector<seqDist> >&, vector<Calculator*>);
     void printDists(ostream&, vector< vector<double> >&, vector<string>);
+    void runCLR(SharedRAbundFloatVectors*&, StructEuclidean*);
 
 };
 	
