@@ -26,6 +26,7 @@ class SharedRAbundVectors : public DataVector {
     
 public:
     SharedRAbundVectors() : DataVector() {  label = ""; numBins = 0; otuTag = "Otu";  }
+    SharedRAbundVectors(string oTag) : DataVector() {  label = ""; numBins = 0; otuTag = oTag;  }
     SharedRAbundVectors(ifstream&, vector<string>& userGroups, string&, string&);
     SharedRAbundVectors(SharedRAbundVectors& bv) : DataVector(bv), numBins(bv.numBins), otuTag(bv.otuTag) {
         vector<SharedRAbundVector*> data = bv.getSharedRAbundVectors();
@@ -61,7 +62,7 @@ public:
     int removeGroups(int minSize, bool silent=false);  // removes any groups with numSeqs < minSize
     int size() { return (int)lookup.size(); }
     void resize(int n) { m->mothurOut("[ERROR]: can not use resize for SharedRAbundVectors.\n"); m->setControl_pressed(true); }
-    void clear() { for (int i = 0; i < lookup.size(); i++) {  if (lookup[i] != NULL) { delete lookup[i];  lookup[i] = NULL; } }  lookup.clear(); groupNames.clear(); numBins = 0; }
+    void clear() { for (int i = 0; i < lookup.size(); i++) {  if (lookup[i] != nullptr) { delete lookup[i];  lookup[i] = nullptr; } }  lookup.clear(); groupNames.clear(); numBins = 0; }
     void print(ostream&, bool&);
     void printTidy(ostream&, bool&, bool);
     
