@@ -34,8 +34,8 @@ class OptiFitCluster : public Cluster {
     
 public:
     
-    OptiFitCluster(OptiData* mt, ClusterMetric* met, long long ns, string crit);
-    ~OptiFitCluster() {}
+    OptiFitCluster(OptiData* mt, ClusterMetric* met, long long ns);
+    ~OptiFitCluster() = default;
     
     int initialize(double& value, bool randomize, vector<vector< string > > existingBins, vector<string>, string, bool);
     bool update(double&); //returns whether list changed and MCC
@@ -49,13 +49,13 @@ public:
     
     ListVector* getList();
     ListVector* getFittedList(string, bool);
+    set<string> getUnfittedNames() { return unfittedNames; }
     
 protected:
     MothurOut* m;
     Utils util;
     ClusterMetric* metric;
     OptiData* matrix;
-    string criteria;
     
     map<long long, long long> seqBin; //sequence# -> bin#
     vector<long long> randomizeSeqs;
@@ -63,6 +63,7 @@ protected:
     map<long long, string> binLabels; //for fitting - maps binNumber to existing reference label
     long long maxRefBinNumber;
     bool closed, denovo;
+    set<string> unfittedNames;
     
     double fittruePositives, fittrueNegatives, fitfalsePositives, fitfalseNegatives, combotruePositives, combotrueNegatives, combofalsePositives, combofalseNegatives;
     long long  numFitSeqs, insertLocation, numFitSingletons;
