@@ -26,19 +26,17 @@ vector<string> ReadPhylipVector::read(vector< vector<double> >& matrix) {
 	try {
 		vector<string> names;
 		
-		ifstream in;
-        Utils util; util.openInputFile(distFile, in);
+		ifstream in; Utils util; util.openInputFile(distFile, in);
 		
 		//check whether matrix is square
 		char d;
-		int square = 1;
-		int numSeqs;
+		int square = 1; int numSeqs;
 		string name;
 		
 		string numTest;
 		in >> numTest >> name;
 		
-		if (!util.isContainingOnlyDigits(numTest)) { m->mothurOut("[ERROR]: expected a number and got " + numTest + ". I suspect you entered a column formatted file as a phylip file, quitting."); m->mothurOutEndLine(); exit(1); }
+		if (!util.isContainingOnlyDigits(numTest)) { m->mothurOut("[ERROR]: expected a number and got " + numTest + ". I suspect you entered a column formatted file as a phylip file, quitting.\n");  exit(1); }
 		else { convert(numTest, numSeqs); }
 		
 		while((d=in.get()) != EOF){
@@ -113,8 +111,7 @@ vector<string> ReadPhylipVector::read(vector<seqDist>& matrix) {
 	try {
 		vector<string> names;
 		
-		ifstream in;
-        Utils util; util.openInputFile(distFile, in);
+		ifstream in; Utils util; util.openInputFile(distFile, in);
 		
 		//check whether matrix is square
 		char d;
