@@ -39,8 +39,10 @@ class ValidCalculators {
 		set<string> vennshared;
 		set<string> treegroup;
 		set<string> matrix;
+        set<string> clr;
 		set<string> heat;
 		set<string> distance;
+        set<string> protdistance;
 		set<string>::iterator it;
 		set<string> allCalcs;
 		
@@ -54,7 +56,9 @@ class ValidCalculators {
 		void initialVennShared();
 		void initialTreeGroups();
 		void initialMatrix();
+        void initialCLR();
 		void initialDistance();
+        void initialProtDistance();
 		void initialHeat();
         void initialEstimators();
     
